@@ -37,6 +37,7 @@ END_GNOME_DECLS
 #include <gtk/gtkadjustment.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtkimcontext.h>
 #include <libzvt/vtx.h>
 #include <libzvt/background.h>
 
@@ -119,8 +120,12 @@ struct _ZvtTerm
   /*GdkColorContext *color_ctx;*/	/* Color context in use, where we allocate our colors */
   /* gulong colors [18];*/	/* Our colors, pixel values. */
   GdkColor colors [18];		/* GdkColor for colormap support */
-  /* GdkIC depecated, needto be substituted with GtkIMContext, not yet done */
-  /* GdkIC *ic;*/		/* input context */
+
+  /* input context */
+  GtkIMContext *ic;
+  guint16 preedit_length;	/* length of preedit string, in bytes */
+  guint16 preedit_cursor;	/* offset of cursor within preedit string, in chars */
+  gboolean      need_im_reset;
 
  /* file name of a pixmap, if NULL, none is loaded
   * and normal mode is used
@@ -279,11 +284,14 @@ void	     zvt_term_set_background		(ZvtTerm       *terminal,
 						 char          *pixmap_file,
 						 int		transparent,
 						 int		flags);
-void         zvt_term_set_background_transparent(ZvtTerm       *term,
-						 int            red,
-						 int            green,
-						 int            blue,
-						 int            alpha);
+void	     zvt_term_set_background_with_shading(ZvtTerm       *terminal,
+                                                  char          *pixmap_file,
+                                                  int		transparent,
+                                                  int		flags,
+                                                  guint16       red,
+                                                  guint16       green,
+                                                  guint16       blue,
+                                                  guint16       alpha);
 void         zvt_term_set_shadow_type           (ZvtTerm       *term,
 						 GtkShadowType  type);
 void         zvt_term_set_size                  (ZvtTerm       *term,
