@@ -1090,7 +1090,7 @@ vt_setmode(struct vt_em *vt, int on)
 	  vt->mode |= VTMODE_BLANK_CURSOR;
 	break;
       case 1047:		/* clear the screen if coming from the alt screen */
-	if (on==0 && (vt->mode&&VTMODE_ALTSCREEN))
+	if (on==0 && (vt->mode&VTMODE_ALTSCREEN))
 	  vt_clear_lines(vt, 0, vt->height);
 	/* falls through */
       case 47:
@@ -1108,6 +1108,19 @@ vt_setmode(struct vt_em *vt, int on)
 	if (on)
 	  vt->mode |= VTMODE_SEND_MOUSE_BOTH;
 	break;
+      case 1049:
+        /* here the application should save the screen and restore it as xterm \does!*/
+        vt_set_screen(vt, on?1:0);
+        if (on)
+          {
+            vt_save_cursor(vt);
+            vt_clear_lines(vt, 1, vt->height);
+          }
+        else
+          {
+            vt_restore_cursor(vt);
+          }
+        break;        
       case 1048:
 	if (on)
 	  vt_save_cursor(vt);
@@ -1539,8 +1552,16 @@ vt_parse_vt (struct vt_em *vt, char *ptr, int length)
 	continue;
       }
     } else {
-      mode = modes[c & 0x7f].modes;
-      process = modes[c & 0x7f].process;
+      if (c < 80)
+	{
+	  mode = modes[c & 0x7f].modes;
+	  process = modes[c & 0x7f].process;
+	}
+      else
+	{
+	  mode = VT_LIT;
+	  process = 0;
+	}
     }
 #else
     mode = modes[c & 0x7f].modes;
